@@ -5,7 +5,7 @@ from .assets import (
     CertificatesAssets,
     DomainsAssets,
     HostsAssets,
-    ObjectStorageAssets,
+    ObjectStoragesAssets,
     SubdomainsAssets,
     WebEntitiesAssets,
 )
@@ -31,25 +31,12 @@ class AsmClient:
         self.hosts = HostsAssets(api_key, **kwargs)
         self.certificates = CertificatesAssets(api_key, **kwargs)
         self.domains = DomainsAssets(api_key, **kwargs)
+        self.subdomains = SubdomainsAssets(api_key, **kwargs)
         self.logbook = Logbook(api_key, **kwargs)
         self.events = self.logbook
         self.clouds = Clouds(api_key, **kwargs)
         self.risks = Risks(api_key, **kwargs)
         self.inventory = InventorySearch(api_key, **kwargs)
-        self.object_storage = ObjectStorageAssets(api_key, **kwargs)
+        self.object_storages = ObjectStoragesAssets(api_key, **kwargs)
         self.web_entities = WebEntitiesAssets(api_key, **kwargs)
         self.beta = Beta(api_key, **kwargs)
-
-        # Save the arguments for parameterized client usage
-        self.__api_kwargs = kwargs
-
-    def get_subdomains(self, domain: str):
-        """Get an API instance for subdomains of the parent domain.
-
-        Args:
-            domain: (str): Parent domain to access.
-
-        Returns:
-            SubdomainsAssets: A Subdomains Assets API instance .
-        """
-        return SubdomainsAssets(domain, self.domains._api_key, **self.__api_kwargs)
