@@ -44,7 +44,11 @@ def fields_completer(
         return []
 
     autocomplete_data = autocomplete_json.get("data", [])
-    fields = [field["value"] for field in autocomplete_data]
+    fields = [
+        field_value
+        for field in autocomplete_data
+        if not (field_value := field["value"]).endswith(".type")
+    ]
 
     if not prefix:
         # Returns first 20 fields if no prefix is provided
@@ -68,7 +72,12 @@ def cli_search(args: argparse.Namespace):
         webbrowser.open(f"https://search.censys.io/search?{urlencode(url_query)}")
         sys.exit(0)
 
-    censys_args = {}
+    if args.timeout < 1:
+        raise CensysCLIException("Timeout must be greater than 0.")
+
+    censys_args = {
+        "timeout": args.timeout,
+    }
 
     if args.api_id:
         censys_args["api_id"] = args.api_id
@@ -88,6 +97,7 @@ def cli_search(args: argparse.Namespace):
         {
             "pages": args.pages,
             "per_page": args.per_page,
+            "fields": args.fields,
         }
     )
     if index_type == "hosts":
@@ -98,12 +108,7 @@ def cli_search(args: argparse.Namespace):
             }
         )
     elif index_type == "certificates":
-        search_args.update(
-            {
-                "sort": args.sort,
-                "fields": args.fields,
-            }
-        )
+        search_args.update({"sort": args.sort})
 
     if args.output and not args.output.endswith(".json"):
         raise CensysCLIException(
@@ -195,6 +200,19 @@ def include(parent_parser: argparse._SubParsersAction, parents: dict):
         type=int,
         help="number of results to return per page",
     )
+    search_parser.add_argument(
+        "--timeout",
+        default=30,
+        type=int,
+        help="number of seconds to wait for a response",
+    )
+    search_parser.add_argument(
+        "--fields",
+        dest="fields",
+        type=str,
+        nargs="+",
+        help="additional fields to return in the matching results",
+    ).completer = fields_completer
 
     hosts_group = search_parser.add_argument_group("hosts specific arguments")
     hosts_group.add_argument(
@@ -222,12 +240,5 @@ def include(parent_parser: argparse._SubParsersAction, parents: dict):
         nargs="+",
         help="fields to sort by",
     )
-    certs_group.add_argument(
-        "--fields",
-        dest="fields",
-        type=str,
-        nargs="+",
-        help="additional fields to return in the matched certificates",
-    ).completer = fields_completer
 
     search_parser.set_defaults(func=cli_search)
